pub trait Matches<T> {
// Required method
fn matches(&self, other: &T) -> bool;
}Expand description
A trait expressing that two items of a type are (potentially fuzzy) matches.
We need a custom trait instead of relying on PartialEq because we allow fuzzy matches.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".